/**
 *  NeSys Pixel Counter plugin
 *  @version 1.1
 *  @author e.a.papp at medisin.uio.no
 *
 *  This ImageJ plugin records the number of black pixels in a (binary) image,
 *  and displays the result in the standard ImageJ Results table.
 * 
 *  The plugin can be applied on a series of images using the macro NeSys_Pixel_Counter_Macro.txt.
 * 
 *  Requires ImageJ version 1.45o or later.
 * 
 *  This plugin is part of a workflow for automated detection of axonal labeling 
 *  in series of microscopic images. See the ImageJ DokuWiki for details:
 *  http://imagejdocu.tudor.lu/doku.php?id=plugin:analysis:autodetection_of_neuronal_labeling_in_histological_image_series:start
 */

import ij.*;
import ij.process.*;
import ij.gui.*;
import ij.plugin.*;
import ij.plugin.filter.Analyzer;
import ij.measure.ResultsTable;

public class NeSys_Pixel_Counter implements PlugIn {

	public void run(java.lang.String arg) {

		if (IJ.versionLessThan("1.45o"))
			return;   		
                ImagePlus imp = IJ.getImage();
  		ImageProcessor ip = imp.getProcessor();
		Analyzer ana = new Analyzer(imp);
		ResultsTable rt = ana.getResultsTable();
		int width = imp.getWidth();
	        int height = imp.getHeight();
		int pxCount = 0;
		float v;
        	imp.killRoi();

	        for (int i=0; i<height; i++) {
        	        for (int j=0; j<width; j++) {
                		v = ip.getPixelValue(j,height-1-i);
	                	if (v==255) {pxCount++;}
	                }
        	}

		rt.incrementCounter();
		rt.disableRowLabels();
		rt.addValue("Filename",imp.getTitle());
		rt.addValue("Pixels",Integer.toString(pxCount));
		rt.addResults();
		rt.updateResults();
	}
}
